(***********************************************************************)
(*                                 DERIV.M                             *)
(* Bernd Fiedler, Fakultaet Math/Inf, Universitaet Leipzig, 05.09.1996 *)
(*                                                                     *)
(*  Spezielle Ableitungsoperatoren fuer das Package VECTAN Version 1.1 *)
(***********************************************************************)


(****************************** Derivative *****************************)
Vect/: Literal[Derivative[n_][Vect[x_]]] := Vect[Derivative[n][x]] ;

(*************************** ResultFunctions ***************************)

Attributes[dotValue] = {HoldAll} ;         (* Argumente: 1 *)
Attributes[graddotValue] = {HoldAll} ;     (* Argumente: 2 *)

(********************************** dot ********************************)

Literal[dot[x_]] := 0 /; NumberQ[x] ;

Literal[dot[x_Symbol]] := 0 /; MemberQ[Attributes[x],Constant] ;

Literal[dot[Vect[Derivative[n_][x_]]]] := (Vect[Derivative[nn][x]] /. 
                                                          {nn -> n+1}) ;

Literal[dot[Vect[x_]]] := dotValue[x] /; ValueQ[dotValue[x]] ;

Literal[dot[Vect[x_]]] := Vect[x'] ;

Literal[dot[Derivative[n_][x_]]] := Derivative[n+1][x] ;

Literal[dot[x_Plus]] := dot /@ x ;

Literal[dot[Times[x_,y__]]] := dot[x] * Times[y] + x * dot[Times[y]] /; 
                                                            !VectQ[x] ;


Literal[dot[SP[x_,y_]]] := SP[dot[x],y] + SP[x,dot[y]] ;

Literal[dot[VP[x_,y_]]] := VP[dot[x],y] + VP[x,dot[y]] ;

Literal[dot[x_]] := dotValue[x] /; ValueQ[dotValue[x]] ;


Literal[rot[Vect[Derivative[n_][x_]]]] := Nest[dot,rotValue[x],n] /;
                                                ValueQ[rotValue[x]];
Literal[div[Vect[Derivative[n_][x_]]]] := Nest[dot,divValue[x],n] /;
                                                ValueQ[divValue[x]];
Literal[grad[Derivative[n_][x_]]] := Nest[dot,gradValue[x],n] /;
                                           ValueQ[gradValue[x]];

Literal[grad[Vect[Derivative[mm_][x_]],Vect[Derivative[nn_][y_]]]] :=
       graddotValue[x,y,mm,nn] /; ValueQ[graddotValue[x,y,mm,nn]];
Literal[grad[x_,Vect[Derivative[nn_][y_]]]] :=
       graddotValue[x,y,0,nn] /; And[VectQ[x],ValueQ[graddotValue[x,y,0,nn]]];
Literal[grad[Vect[Derivative[mm_][x_]]]] :=
       graddotValue[x,y,mm,0] /; And[VectQ[y],ValueQ[graddotValue[x,y,mm,0]]];

Literal[dot[grad[x_]]] := grad[dot[x]] ;
Literal[dot[grad[x_,y_]]] := grad[dot[x],y] + grad[x,dot[y]] ;
Literal[dot[div[x_]]] := div[dot[x]] ;
Literal[dot[rot[x_]]] := rot[dot[x]] ;

Literal[dot[f_[x__]]] :=
Chain[f,List[x],dot[#]&] /; And[!MatchQ[f,Derivative[__]],
                               And @@ (!VectQ[#]&) /@ List[x]
                               ];

Literal[dot[x_]] := x' /; !VectQ[x] ;
